@@ -24,6 +24,20 @@
 
 #include <stdint.h>
 
+
+/**
+ * Generates a number of random bytes.
+ *
+ * @param buf
+ *    Pointer to a buffer that receives the random data. Must have a size
+ *    of at least <code>length</code> bytes.
+ *
+ * @param length
+ *    Number of random bytes to produce.
+ */
+void randomZRTP(uint8_t *buf, int32_t length);
+
+
 /**
  * Implementation of Diffie-Helman for ZRTP
  *
@@ -34,13 +48,15 @@
  *
  * @author Werner Dittmann <Werner.Dittmann@t-online.de>
  */
+
 class ZrtpDH {
 
 private:
     void* ctx;
+    int32_t pkLength;
 
 public:
-    ZrtpDH(int32_t pkLength);
+    ZrtpDH(int32_t pl);
     ~ZrtpDH();
 
     /**
@@ -114,17 +130,7 @@ public:
      */
     int32_t checkPubKey(uint8_t* pubKeyBytes, int32_t length) const;
 
-    /**
-     * Generates a number of random bytes.
-     *
-     * @param buf
-     *    Pointer to a buffer that receives the random data. Must have a size
-     *    of at least <code>length</code> bytes.
-     *
-     * @param length
-     *    Number of random bytes to produce.
-     */
-    void random(uint8_t *buf, int32_t length);
+    int32_t getDHlength() { return pkLength; }
 };
 
 #endif // ZRTPDH_H
